@@ -16,6 +16,7 @@ Pool actions.
 """
 
 # isort: STDLIB
+import json
 import os
 from collections import defaultdict
 from itertools import tee
@@ -185,7 +186,6 @@ class PoolActions:
             proxy,
             {
                 "name": pool_name,
-                "redundancy": (True, 0),
                 "devices": blockdevs,
                 "key_desc": (
                     (True, namespace.key_desc)
@@ -194,7 +194,7 @@ class PoolActions:
                 ),
                 "clevis_info": (False, ("", ""))
                 if clevis_info is None
-                else (True, clevis_info),
+                else (True, (clevis_info.pin, json.dumps(clevis_info.config))),
             },
         )
 
@@ -313,7 +313,7 @@ class PoolActions:
             get_object(pool_object_path), {"devices": blockdevs}
         )
 
-        if return_code != StratisdErrors.OK:
+        if return_code != StratisdErrors.OK:  # pragma: no cover
             raise StratisCliEngineError(return_code, message)
 
         if not changed or len(devs_added) < len(blockdevs):  # pragma: no cover
